@@ -145,3 +145,9 @@ class ListThumbnail(ListWidget):
 
 class ListCarousel(ListWidget):
     template = 'appbuilder/general/widgets/list_carousel.html'
+
+class ListItem(ListWidget):
+    template = 'appbuilder/general/widgets/list_item.html'
+
+class ListBlock(ListWidget):
+    template = 'appbuilder/general/widgets/list_block.html'
